SmellDetector

Struct SmellDetector 

pub struct SmellDetector { /* private fields */ }
Main smell detector that runs all enabled detectors.

Implementations

Source

impl SmellDetector

pub fn new() -> Self

Create a new smell detector with default configuration.

pub fn with_config(config: SmellConfig) -> Self

Create a new smell detector with the given configuration.

pub fn from_config_file(path: &Path) -> Result<Self>

Load configuration from a file.

pub fn config(&self) -> &SmellConfig

Get the current configuration.

pub fn min_severity(&self) -> Severity

Get minimum severity from config.

pub fn analyze_file(&self, path: &Path) -> Result<Report>

Analyze a file (L5X or PLCopen) and return a report.

pub fn analyze(&self, project: &LoadedProject) -> Result<Report>

Analyze a loaded project.

pub fn analyze_controller(&self, controller: &Controller) -> Result<Report>

Analyze a parsed L5X controller.

pub fn get_stats_file(&self, path: &Path) -> Result<ParseStats>

Get statistics for a file without running smell detection.

pub fn get_stats(&self, project: &LoadedProject) -> Result<ParseStats>

Get statistics for a loaded project (L5X format).

pub fn get_plcopen_stats(&self, project: &LoadedProject) -> Result<PlcopenStats>

Get PLCopen statistics for a loaded project.